==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7cee5a5107c8bbed javax_swing_plaf_BorderUIResource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource$fields_struct {
	struct _jc_object	*blackLineBorderUIResource;
	struct _jc_object	*etchedBorderUIResource;
	struct _jc_object	*loweredBevelBorderUIResource;
	struct _jc_object	*raisedBevelBorderUIResource;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource$method$_init$ea8eb7f460af3899(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_BorderUIResource$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_BorderUIResource$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *);
extern void _jc_javax_swing_plaf_BorderUIResource$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_BorderUIResource$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_BorderUIResource$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_BorderUIResource$method_info$paintBorder$4a79b2eae89db578;

// Static methods
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getBlackLineBorderUIResource$43b168fa1fcea39a(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getEtchedBorderUIResource$9d8d0dc223a6e568(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getLoweredBevelBorderUIResource$9052687929902ace(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getRaisedBevelBorderUIResource$c58e8a42d852c353(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_BorderUIResource$vmethods	javax_swing_plaf_BorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource$sub_refs {
	struct _jc_object	*delegate;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_BorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7cee5a5107c8bbed javax_swing_plaf_BorderUIResource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource$fields_struct {
	struct _jc_object	*blackLineBorderUIResource;
	struct _jc_object	*etchedBorderUIResource;
	struct _jc_object	*loweredBevelBorderUIResource;
	struct _jc_object	*raisedBevelBorderUIResource;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource$method$_init$ea8eb7f460af3899(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_BorderUIResource$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_BorderUIResource$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_BorderUIResource$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_BorderUIResource$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_BorderUIResource$method_info$paintBorder$4a79b2eae89db578;

// Static methods
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getBlackLineBorderUIResource$43b168fa1fcea39a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getEtchedBorderUIResource$9d8d0dc223a6e568(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getLoweredBevelBorderUIResource$9052687929902ace(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_BorderUIResource$method$getRaisedBevelBorderUIResource$c58e8a42d852c353(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_BorderUIResource$vmethods	javax_swing_plaf_BorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource$sub_refs {
	struct _jc_object	*delegate;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_BorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource_H_ */
